@@ -9,7 +9,6 @@
 const char *ripe_servers[] = {
     "whois.ripe.net",
     "whois.apnic.net",
-    "whois.oleane.net",
     "whois.denic.de",
     "rr.arin.net",		/* does not accept the old syntax */
     "whois.6bone.net",		/* 3.0.0b1 */
@@ -102,25 +101,47 @@ struct ip_del ip_assign[] = {
 };
 
 struct ip6_del {
-    unsigned long net;		/* bits 16-22 of the address */
+    unsigned char net;		/* bits 16-21 of the address */
     const char    *serv;
 };
 
 /* http://www.iana.org./assignments/ipv6-tla-assignments */
 struct ip6_del ip6_assign[] = {
-    { 0x0200, "whois.apnic.net" },
-    { 0x0400, "whois.arin.net" },
-    { 0x0600, "whois.ripe.net" },
-    { 0x0800, "whois.ripe.net" },
-    { 0x0A00, "whois.ripe.net" },
-    { 0x0C00, "whois.apnic.net" },
-    { 0x0E00, "whois.apnic.net" },
-/*  { 0x1000, "" }, */
-    { 0x1200, "whois.lacnic.net" },
-    { 0x1400, "whois.ripe.net" },
-    { 0x1600, "whois.ripe.net" },
-    { 0x1800, "whois.arin.net" },
-    { 0x1A00, "whois.ripe.net" },
+    { 0x02, "whois.apnic.net" },
+    { 0x04, "whois.arin.net" },
+    { 0x06, "whois.ripe.net" },
+    { 0x08, "whois.ripe.net" },
+    { 0x0A, "whois.ripe.net" },
+    { 0x0C, "whois.apnic.net" },
+    { 0x0E, "whois.apnic.net" },
+/*  { 0x10, "" }, */
+    { 0x12, "whois.lacnic.net" },
+    { 0x14, "whois.ripe.net" },
+    { 0x16, "whois.ripe.net" },
+    { 0x18, "whois.arin.net" },
+    { 0x1A, "whois.ripe.net" },
+    { 0x1C, "whois.ripe.net" },
+    { 0x1E, "whois.ripe.net" },
+    { 0x20, "whois.ripe.net" },
+    { 0x22, "whois.ripe.net" },
+    { 0x24, "whois.ripe.net" },
+    { 0x26, "whois.ripe.net" },
+    { 0x28, "whois.ripe.net" },
+    { 0x2A, "whois.ripe.net" },
+    { 0x2C, "whois.ripe.net" },
+    { 0x2E, "whois.ripe.net" },
+    { 0x30, "whois.ripe.net" },
+    { 0x32, "whois.ripe.net" },
+    { 0x34, "whois.ripe.net" },
+    { 0x36, "whois.ripe.net" },
+    { 0x38, "whois.ripe.net" },
+    { 0x3A, "whois.ripe.net" },
+    { 0x40, "whois.ripe.net" },
+    { 0x41, "whois.ripe.net" },
+    { 0x42, "whois.arin.net" },
+    { 0x43, "whois.arin.net" },
+    { 0x44, "whois.apnic.net" },
+    { 0x45, "whois.apnic.net" },
     { 0, NULL }
 };
 
